@@ -1,5 +1,5 @@
 ;;; howm-vars.el --- Wiki-like note-taking tool
-;;; Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2015
+;;; Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2015, 2016
 ;;;   HIRAOKA Kazuyuki <khi@users.sourceforge.jp>
 ;;; $Id: howm-vars.el,v 1.59 2011-12-31 15:07:29 hira Exp $
 ;;;
@@ -19,15 +19,15 @@
 ;;; USA.
 ;;--------------------------------------------------------------------
 
-(require 'howm-cl)
+(require 'cl-lib)
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Util
 
 (defmacro howm-define-risky-command (risky orig)
   "Define a macro RISKY which is risky-version of ORIG."
-  (let* ((gsymbol (howm-cl-gensym))
-         (gargs (howm-cl-gensym))
+  (let* ((gsymbol (cl-gensym))
+         (gargs (cl-gensym))
          (docstring (format "Do `%s' and set risky-local-variable property."
                             orig)))
     `(defmacro ,risky
@@ -40,7 +40,7 @@
 ;; I split this function from howm-define-risky-command for avoiding
 ;; nested backquotes. Nested backquotes are byte-compiled to
 ;; old-style-backquotes, that cause warnings when *.elc is loaded.
-(eval-when (compile load eval)
+(cl-eval-when (compile load eval)
   (defun howm-define-risky-command-body (command symbol args)
     `(progn
        (,command ,symbol ,@args)
@@ -49,8 +49,8 @@
 ;; ;; This code is byte-compiled to old-style-backquotes. Sigh...
 ;; (defmacro howm-define-risky-command (risky orig)
 ;;   "Define a macro RISKY which is risky-version of ORIG."
-;;   (let* ((gsymbol (howm-cl-gensym))
-;;          (gargs (howm-cl-gensym))
+;;   (let* ((gsymbol (cl-gensym))
+;;          (gargs (cl-gensym))
 ;;          (docstring (format "Do `%s' and set risky-local-variable property."
 ;;                             orig)))
 ;;     `(progn
@@ -134,7 +134,7 @@ as default of some variables; put (setq howm-compatible-to-ver1dot3 t)
 
 (defmacro howm-if-ver1dot3 (oldval def)
   (declare (indent 1))
-  (destructuring-bind (command var val &rest args) def
+  (cl-destructuring-bind (command var val &rest args) def
     `(,command ,var (if howm-compatible-to-ver1dot3 ,oldval ,val)
                ,@args
                :group 'howm-compatibility)))
@@ -204,32 +204,33 @@ To avoid such troubles, this variable is prepared as a fixed string.")
         (string-match "windows" (symbol-name system-type)))
       "[/\\\\]" ;; / or \ for win
     "/")) ;; / otherwise
+
 (let ((dir-head (concat "\\(^\\|" howm-excluded-file-regexp-dir-sep "\\)"))
       (excluded-dirs (concat (regexp-opt howm-excluded-dirs t)
-                   howm-excluded-file-regexp-dir-sep)))
-  (defvar howm-excluded-file-regexp-dots-ok
-    (mapconcat #'identity
-               `(,(concat dir-head excluded-dirs)
-                 "^[.][.]"
-                 ,@howm-excluded-file-regexp-common-list)
-               "\\|"))
-  (defvar howm-excluded-file-regexp-dots-ng
-    (mapconcat #'identity
-               `(,(concat dir-head "\\([.]\\|" excluded-dirs "\\)")
-                 ,@howm-excluded-file-regexp-common-list)
-               "\\|")))
-
-(howm-defcustom-risky howm-excluded-file-regexp howm-excluded-file-regexp-dots-ng
-  "Regexp for excluded files.
+                             howm-excluded-file-regexp-dir-sep)))
+  (let ((howm-excluded-file-regexp-dots-ok
+         (mapconcat #'identity
+                    `(,(concat dir-head excluded-dirs)
+                      "^[.][.]"
+                      ,@howm-excluded-file-regexp-common-list)
+                    "\\|"))
+        (howm-excluded-file-regexp-dots-ng
+         (mapconcat #'identity
+                    `(,(concat dir-head "\\([.]\\|" excluded-dirs "\\)")
+                      ,@howm-excluded-file-regexp-common-list)
+                    "\\|")))
+    (howm-defcustom-risky howm-excluded-file-regexp
+                          howm-excluded-file-regexp-dots-ng
+      "Regexp for excluded files.
 It is checked for relative paths from howm-directory and howm-search-path.
 A file is excluded iff this regexp matches with all the relative paths."
-  :type `(radio (const :tag "Don't search dot files"
-                       ,howm-excluded-file-regexp-dots-ng)
-                (const :tag "Search dot files"
-                       ,howm-excluded-file-regexp-dots-ok)
-                regexp)
-  :group 'howm-files
-  )
+      :type `(radio (const :tag "Don't search dot files"
+                           ,howm-excluded-file-regexp-dots-ng)
+                    (const :tag "Search dot files"
+                           ,howm-excluded-file-regexp-dots-ok)
+                    regexp)
+      :group 'howm-files
+      )))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Menu
@@ -305,10 +306,10 @@ A file is excluded iff this regexp matches with all the relative paths."
     (if (not (string-match "^\\[\\(.*\\)\\]" reg))
         reg
       (let ((types (split-string (match-string-no-properties 1 reg) "")))
-        (if (howm-cl-find-if-not (lambda (x) (member x default-types))
+        (if (cl-find-if-not (lambda (x) (member x default-types))
                                  types)
             reg
-          (howm-cl-remove-if-not (lambda (x) (member x types))
+          (cl-remove-if-not (lambda (x) (member x types))
                                  default-types))))))
 (defun howm-custom-reminder-set-types (symbol types)
   (when (listp types)
@@ -1194,6 +1195,38 @@ Note: `howm-menu-font-lock-rules' overrides this variable."
   "Test of experimental features."
   :group 'howm)
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; Date format (need refactoring)
+
+(defvar howm-date-separator "-") ;; "-" ==> 2003-10-21
+
+;; Fix me: redundant (howm-date-* & howm-reminder-*)
+;; (cf.) howm-reminder-regexp-grep-* howm-reminder-today-format
+(defvar howm-date-regexp-grep
+  (concat "[1-2][0-9][0-9][0-9]" howm-date-separator
+          "[0-1][0-9]" howm-date-separator
+          "[0-3][0-9]"))
+(defvar howm-date-regexp
+  (concat "\\([1-2][0-9][0-9][0-9]\\)" howm-date-separator
+          "\\([0-1][0-9]\\)" howm-date-separator
+          "\\([0-3][0-9]\\)"))
+(defvar howm-date-regexp-year-pos 1)
+(defvar howm-date-regexp-month-pos 2)
+(defvar howm-date-regexp-day-pos 3)
+(defvar howm-date-format
+  (concat "%Y" howm-date-separator "%m" howm-date-separator "%d"))
+(defvar howm-dtime-body-format
+  (concat howm-date-format " %H:%M"))
+(defvar howm-dtime-format
+  (concat "[" howm-dtime-body-format "]"))
+(defvar howm-insert-date-format "[%s]")
+(defvar howm-insert-date-future nil)
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; Avoid reference to free variable (need refactoring)
+
+(howm-defvar-risky howm-menu-action-arg 'howm-menu-action-arg-name)
+
 ;;;
 
 (provide 'howm-vars)
