@@ -1,22 +1,26 @@
 ;;; howm.el --- Wiki-like note-taking tool
-;;; Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2015
-;;;   HIRAOKA Kazuyuki <khi@users.sourceforge.jp>
-;;; $Id: howm.el,v 1.22 2011-12-31 15:07:29 hira Exp $
-;;;
-;;; This program is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 1, or (at your option)
-;;; any later version.
-;;;
-;;; This program is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; The GNU General Public License is available by anonymouse ftp from
-;;; prep.ai.mit.edu in pub/gnu/COPYING.  Alternately, you can write to
-;;; the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139,
-;;; USA.
+
+;; Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2015, 2016 HIRAOKA Kazuyuki
+
+;; Author: HIRAOKA Kazuyuki <khi@users.sourceforge.jp>
+;; URL: http://howm.osdn.jp
+;; Version: 1.4.3
+;; Package-Requires: ((cl-lib "0.5"))
+
+;; This program is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 1, or (at your option)
+;; any later version.
+
+;; This program is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+
+;; The GNU General Public License is available by anonymouse ftp from
+;; prep.ai.mit.edu in pub/gnu/COPYING.  Alternately, you can write to
+;; the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139,
+;; USA.
 ;;--------------------------------------------------------------------
 
 ;;; DESCRIPTION:
@@ -36,9 +40,15 @@
 
 ;;; [1] cl
 
-(require 'howm-cl)
+(require 'cl-lib)
 
-;;; [2] my tools
+;;; [2] howm basic libraries
+
+(require 'howm-version)
+(require 'howm-vars)
+(require 'howm-common)
+
+;;; [3] my tools
 
 ;; This doesn't work in byte-compilation. I don't understand it. Sigh...
 ;; (mapcar #'require howm-required-features)
@@ -50,12 +60,6 @@
 (require 'action-lock)
 (require 'honest-report)
 
-;;; [3] howm basic libraries
-
-(require 'howm-version)
-(require 'howm-vars)
-(require 'howm-common)
-
 ;;; [4] howm main (this file)
 
 (provide 'howm)
